# High-level python interface to the Neo4j graph database

https://brainannex.org/guide.php


This library used to be distributed as part of the full technology stack "Brain Annex";
but, starting with version 4.0.3, it's being independently released.

To use it, just `pip install neoaccess`


[Intro and tutorial](https://julianspolymathexplorations.blogspot.com/2023/06/neo4j-python-neoaccess-library.html)
